@@ -111,6 +111,18 @@ class URLTarget(object):
         url_parts[4] = urlparse.urlencode(query)
         return urlparse.urlunparse(url_parts)
 
+    def _extend_sciebo_url(self, url: str) -> str:
+        """
+            Adds the string /download to a URL containing 'sciebo.de'
+            @param url: The URL where the string should be added.
+            @return: The URL with the string.
+        """
+        if 'sciebo.de' in url and 'download' not in url:
+            url_parts = list(urlparse.urlparse(url))
+            url_parts[2] = url_parts[2].strip('/') + '/download'
+            url = urlparse.urlunparse(url_parts)
+        return url
+
     def create_dir(self, path: str):
         # Creates the folders of a path if they do not exist.
         if not os.path.exists(path):
@@ -346,6 +358,9 @@ class URLTarget(object):
         if add_token:
             url_to_download = self._add_token_to_url(self.file.content_fileurl)
 
+        # adds /download to sciebo.de urls
+        url_to_download = self._extend_sciebo_url(self.file.content_fileurl)
+
         cookies_path = self.options.get('cookies_path', None)
         if use_cookies:
             if cookies_path is None or not os.path.isfile(cookies_path):
@@ -427,7 +442,7 @@ class URLTarget(object):
 
         if isHTML and not self.is_blocked_for_youtube_dl(url_to_download):
 
-            filename_tmpl = self.filename + ' | %(title)s (%(id)s).%(ext)s'
+            filename_tmpl = self.filename + ' - %(title)s (%(id)s).%(ext)s'
             if self.file.content_type == 'description-url':
                 filename_tmpl = '%(title)s (%(id)s).%(ext)s'
             outtmpl = str(Path(self.destination) / filename_tmpl)
@@ -676,6 +691,29 @@ class URLTarget(object):
 
         return False
 
+    def store_data_url(self):
+        url_to_download = self.file.content_fileurl
+        logging.debug('T%s - Data-URL detected', self.thread_id)
+        try:
+            os.remove(self.file.saved_to)
+        except Exception as e:
+            logging.warning(
+                'T%s - Could not delete %s before storing data url. Error: %s',
+                self.thread_id,
+                self.file.saved_to,
+                e,
+            )
+        self.set_path(True)
+        with urllib.request.urlopen(url_to_download) as response:
+            data = response.read()
+
+        with open(self.file.saved_to, "wb") as target_file:
+            target_file.write(data)
+
+        self.set_utime()
+        self.file.time_stamp = int(time.time())
+        self.success = True
+
     def download(self, thread_id: int):
         """
         Downloads a file
@@ -732,6 +770,10 @@ class URLTarget(object):
                     self.try_download_link(add_token, False, False)
                 return self.success
 
+            if self.file.content_fileurl.startswith('data:'):
+                self.store_data_url()
+                return self.success
+
             url_to_download = self.file.content_fileurl
             logging.debug('T%s - Downloading %s', self.thread_id, url_to_download)
 
