@@ -31,6 +31,7 @@ class DefaultKeys:
     Attributes:
         interrupt(List[str]): Keys that cause a keyboard interrupt.
         select(List[str]): Keys that trigger list element selection.
+        select_all(List[str]): Keys that trigger selection of all list elements.
         confirm(List[str]): Keys that trigger list confirmation.
         delete(List[str]): Keys that trigger character deletion.
         down(List[str]): Keys that select the element below.
@@ -39,6 +40,7 @@ class DefaultKeys:
 
     interrupt: List[str] = [readchar.key.CTRL_C, readchar.key.CTRL_D]
     select: List[str] = [readchar.key.SPACE]
+    select_all: List[str] = [readchar.key.CTRL_A]
     confirm: List[str] = [readchar.key.ENTER, readchar.key.CR, readchar.key.LF]
     delete: List[str] = [readchar.key.BACKSPACE]
     down: List[str] = [readchar.key.DOWN, 'j']
@@ -273,6 +275,10 @@ def select_multiple(
                 error_message = f'Must select at most {maximal_count} options'
             else:
                 break
+        elif keypress in DefaultKeys.select_all:
+            for i in range(0, max_index+1):
+                if i not in ticked_indices:
+                    ticked_indices.append(i)
         elif keypress in DefaultKeys.interrupt:
             raise KeyboardInterrupt
     print('\033[1A\033[K', end='', flush=True)
@@ -307,7 +313,13 @@ def prompt_yes_or_no(
     is_yes = default_is_yes
     is_selected = enter_empty_confirms
     current_message = ''
-    yn_prompt = f' ({yes_text[0]}/{no_text[0]}) ' if char_prompt else ': '
+    if char_prompt:
+        if default_is_yes:
+            yn_prompt = f' ({yes_text[0]}/{no_text[0].lower()}) '
+        else:
+            yn_prompt = f' ({yes_text[0].lower()}/{no_text[0]}) '
+    else:
+        yn_prompt = ': '
     print()
     while True:
         yes = is_yes and is_selected
